import{S as s,E as e}from"../../../../c.5cd5d307.js";let n=!1;self.onmessage=a=>{n||function(a){if(n)return;n=!0;const o=new s((s=>{self.postMessage(s)}),(s=>new e(s,a)));self.onmessage=s=>{o.onmessage(s.data)}}(null)};
