const e=(e,t,o,c)=>{c=c||{};const n=new CustomEvent(t,{bubbles:void 0===c.bubbles||c.bubbles,cancelable:Boolean(c.cancelable),composed:void 0===c.composed||c.composed,detail:o});e.dispatchEvent(n)},t=(e,t="")=>{const o=new Blob([e],{type:"text/plain"}),c=URL.createObjectURL(o);((e,t="")=>{const o=document.createElement("a");o.target="_blank",o.href=e,o.download=t,document.body.appendChild(o),o.dispatchEvent(new MouseEvent("click")),document.body.removeChild(o)})(c,t),setTimeout((()=>URL.revokeObjectURL(c)),0)};export{e as f,t};
