import{_ as e,w as s,n as o,y as l}from"./c.998383f4.js";import"./c.79283163.js";import"./c.5b9dec44.js";import"./c.abbbe9de.js";let a=class extends o{render(){return l`
      <esphome-process-dialog
        heading="Update All"
        .type=${"update-all"}
        @closed=${this._handleClose}
      ></esphome-process-dialog>
    `}_handleClose(){this.parentNode.removeChild(this)}};a=e([s("esphome-update-all-dialog")],a);
